RealCombination
===============

.. currentmodule:: pykeen.nn.combinations

.. autoclass:: RealCombination
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RealCombination.forward
      ~RealCombination.score

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: score
